https://bugs.koha-community.org/bugzilla3/show_bug.cgi?id=42835
Jonathan Druart <[email protected]> changed: What |Removed |Added ---------------------------------------------------------------------------- CC| |[email protected] See Also| |https://bugs.koha-community | |.org/bugzilla3/show_bug.cgi | |?id=38181 --- Comment #73 from Jonathan Druart <[email protected]> --- >From https://bugs.koha-community.org/bugzilla3/attachment.cgi?id=207793 Bug 38181: Look up item statuses once per record in buildKohaItemsNamespace On a record with 1000 items (koha-testing-docker) the routine goes from 0.85s to 0.09s, and an OPAC searchResults call for that record from 1.2s to 0.45s. -- You are receiving this mail because: You are watching all bug changes. _______________________________________________ Koha-bugs mailing list -- [email protected] To unsubscribe send an email to [email protected] website : http://www.koha-community.org/ git : http://git.koha-community.org/ bugs : http://bugs.koha-community.org/
